summaryrefslogtreecommitdiffstats
path: root/Http/Authorization/AccessDeniedHandlerInterface.php
diff options
context:
space:
mode:
Diffstat (limited to 'Http/Authorization/AccessDeniedHandlerInterface.php')
-rw-r--r--Http/Authorization/AccessDeniedHandlerInterface.php11
1 files changed, 6 insertions, 5 deletions
diff --git a/Http/Authorization/AccessDeniedHandlerInterface.php b/Http/Authorization/AccessDeniedHandlerInterface.php
index 8474fce..c33353b 100644
--- a/Http/Authorization/AccessDeniedHandlerInterface.php
+++ b/Http/Authorization/AccessDeniedHandlerInterface.php
@@ -5,6 +5,7 @@ namespace Symfony\Component\Security\Http\Authorization;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Event\ExceptionEvent;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
+use Symfony\Component\HttpKernel\Event\GetResponseForExceptionEvent;
/**
* This is used by the ExceptionListener to translate an AccessDeniedException
@@ -17,11 +18,11 @@ interface AccessDeniedHandlerInterface
/**
* Handles an access denied failure.
*
* @param ExceptionEvent $event
* @param Request $request
* @param AccessDeniedException $accessDeniedException
*
* @return Response may return null
*/
- function handle(ExceptionEvent $event, Request $request, AccessDeniedException $accessDeniedException);
-} \ No newline at end of file
+ function handle(GetResponseForExceptionEvent $event, Request $request, AccessDeniedException $accessDeniedException);
+}
@@ -17,11 +18,11 @@ interface AccessDeniedHandlerInterface
* Handles an access denied failure.
*
- * @param ExceptionEvent $event
- * @param Request $request
- * @param AccessDeniedException $accessDeniedException
+ * @param GetResponseForExceptionEvent $event
+ * @param Request $request
+ * @param AccessDeniedException $accessDeniedException
*
* @return Response may return null